<template>
  <a-card
    :bordered="false"
    :class="'cust-erp-sub-tab'"
  >
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
        </a-row>
      </a-form>
    </div>
    <div>
      <!-- <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div> -->

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :scroll="{ x: 'calc(1500px + 50%)', y: 900 }"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        @change="handleTableChange"
      >

      </a-table>
    </div>

    <project-maintenance-order-detail-modal
      ref="modalForm"
      @ok="modalFormOk"
      :mainId="mainId"
    ></project-maintenance-order-detail-modal>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import ProjectMaintenanceOrderDetailModal from './ProjectMaintenanceOrderDetailModal'

export default {
  name: "ProjectMaintenanceOrderDetailList",
  mixins: [JeecgListMixin],
  components: { ProjectMaintenanceOrderDetailModal },
  props: {
    mainId: {
      type: String,
      default: '',
      required: false
    }
  },
  watch: {
    mainId: {
      immediate: true,
      handler(val) {
        if (!this.mainId) {
          this.clearList()
        } else {
          this.queryParam['projectMaintenanceOrderId'] = val
          this.loadData(1);
        }
      }
    }
  },
  data() {
    return {
      description: '项目性维修页面',
      disableMixinCreated: true,
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '状态',
          align: 'center',
          dataIndex: 'typeStatus_dictText'
        },
        {
          title: '任务编码',
          align: "center",
          dataIndex: 'taskNum'
        },
        {
          title: '设备编码',
          align: "center",
          dataIndex: 'equipmentNum'
        },
        /* {
           title:'资产编码',
           align:"center",
           dataIndex: 'assetNumber'
         },*/
        /* {
           title:'特种设备',
           align:"center",
           dataIndex: 'specificEquipment_dictText',
         },*/
        {
          title: '设备名称',
          align: "center",
          dataIndex: 'equipmentName'
        },
        {
          title: '设备型号',
          align: "center",
          dataIndex: 'model'
        },
        {
          title: '设备规格',
          align: "center",
          dataIndex: 'specification'
        },
        {
          title: '维保方式',
          align: "center",
          dataIndex: 'maintenanceMode_dictText'
        },
        {
          title: '项目内容',
          align: "center",
          dataIndex: 'itemName'
        },
        {
          title: '紧急程度',
          align: "center",
          dataIndex: 'urgency_dictText'
        },
        {
          title: '责任班组',
          align: "center",
          dataIndex: 'teamId_dictText',

        },
        {
          title: '责任人',
          align: "center",
          dataIndex: 'userId_dictText',

        },
        {
          title: '计划开始时间',
          align: "center",
          dataIndex: 'planStartTime',
          // customRender:function (text) {
          //   return !text?"":(text.length>10?text.substr(0,10):text)
          // }

        },
        {
          title: '计划结束时间',
          align: "center",
          dataIndex: 'planEndTime',
          // customRender:function (text) {
          //   return !text?"":(text.length>10?text.substr(0,10):text)
          // }
        },
        {
          title: '实际开始时间',
          align: "center",
          dataIndex: 'actualStartTime',
          // customRender:function (text) {
          //   return !text?"":(text.length>10?text.substr(0,10):text)
          // }
        },
        {
          title: '实际完成时间',
          align: "center",
          dataIndex: 'actualEndTime',
          // customRender:function (text) {
          //   return !text?"":(text.length>10?text.substr(0,10):text)
          // }
        },
        // {
        //   title: '操作',
        //   dataIndex: 'action',
        //   align:"center",
        //   fixed:"right",
        //   width:147,
        //   scopedSlots: { customRender: 'action' },
        // }
      ],
      url: {
        list: "/eam/projectMaintenanceOrder/listProjectMaintenanceOrderDetailByMainId",
        delete: "/eam/projectMaintenanceOrder/deleteProjectMaintenanceOrderDetail",
        deleteBatch: "/eam/projectMaintenanceOrder/deleteBatchProjectMaintenanceOrderDetail",
        exportXlsUrl: "/eam/projectMaintenanceOrder/exportProjectMaintenanceOrderDetail",
        importUrl: "/eam/projectMaintenanceOrder/importProjectMaintenanceOrderDetail",
      },
      dictOptions: {
        auditStatus: [],
      }
    }
  },
  created() {
  },
  computed: {
    importExcelUrl() {
      return `${window._CONFIG['domianURL']}/${this.url.importUrl}/${this.mainId}`;
    }
  },
  methods: {
    clearList() {
      this.dataSource = []
      this.selectedRowKeys = []
      this.ipagination.current = 1
    }

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>
